@@ -3,7 +3,7 @@
 /*
  *  Goo
  *
- *  Copyright (C) 2004 Free Software Foundation, Inc.
+ *  Copyright (C) 2004-2009 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@
 #define GOO_PLAYER_H
 
 #include <glib.h>
-#include <glib-object.h>
-#include "song-info.h"
+#include <gio/gio.h>
+#include <brasero3/brasero-drive.h>
+#include "track-info.h"
+#include "album-info.h"
 
 #define GOO_TYPE_PLAYER              (goo_player_get_type ())
 #define GOO_PLAYER(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOO_TYPE_PLAYER, GooPlayer))
@@ -34,9 +36,9 @@
 #define GOO_IS_PLAYER_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GOO_TYPE_PLAYER))
 #define GOO_PLAYER_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GOO_TYPE_PLAYER, GooPlayerClass))
 
-typedef struct _GooPlayer            GooPlayer;
-typedef struct _GooPlayerClass       GooPlayerClass;
-typedef struct _GooPlayerPrivateData GooPlayerPrivateData;
+typedef struct _GooPlayer        GooPlayer;
+typedef struct _GooPlayerClass   GooPlayerClass;
+typedef struct _GooPlayerPrivate GooPlayerPrivate;
 
 typedef enum {
 	GOO_PLAYER_ACTION_NONE,
@@ -46,13 +48,16 @@ typedef enum {
 	GOO_PLAYER_ACTION_PLAY,
 	GOO_PLAYER_ACTION_PAUSE,
 	GOO_PLAYER_ACTION_STOP,
-	GOO_PLAYER_ACTION_EJECT,
+	GOO_PLAYER_ACTION_MEDIUM_REMOVED,
+	GOO_PLAYER_ACTION_MEDIUM_ADDED,
 	GOO_PLAYER_ACTION_UPDATE,
 	GOO_PLAYER_ACTION_METADATA
 } GooPlayerAction;
 
 typedef enum {
 	GOO_PLAYER_STATE_ERROR,
+	GOO_PLAYER_STATE_NO_DISC,
+	GOO_PLAYER_STATE_DATA_DISC,
 	GOO_PLAYER_STATE_STOPPED,
 	GOO_PLAYER_STATE_PLAYING,
 	GOO_PLAYER_STATE_PAUSED,
@@ -65,32 +70,13 @@ typedef enum {
 struct _GooPlayer
 {
 	GObject __parent;
-	GooPlayerPrivateData *priv;
+	GooPlayerPrivate *priv;
 };
 
 struct _GooPlayerClass
 {
 	GObjectClass __parent_class;
 
-	/*<virtual functions>*/
-
-	void        (*update)            (GooPlayer       *player);
-	void        (*list)              (GooPlayer       *player);
-	void        (*seek_song)         (GooPlayer       *player,
-					  gint             n);
-	SongInfo *  (*get_song)          (GooPlayer       *player,
-					  gint             n);
-	void        (*skip_to)           (GooPlayer       *player,
-					  guint            seconds);
-	void        (*play)              (GooPlayer       *player);
-	void        (*pause)             (GooPlayer       *player);
-	void        (*stop)              (GooPlayer       *player);
-	gboolean    (*eject)             (GooPlayer       *player);
-	GList *     (*get_song_list)     (GooPlayer       *player);
-	gboolean    (*set_location)      (GooPlayer       *player,
-					  const char      *location);
-	void        (*set_volume)        (GooPlayer       *player,
-					  int              vol);
 	/*<signals>*/
 
 	void        (*start)             (GooPlayer       *player,
@@ -106,51 +92,35 @@ struct _GooPlayerClass
 };
 
 GType            goo_player_get_type            (void);
-void             goo_player_construct           (GooPlayer       *player,
-						 const char      *location);
+GooPlayer *      goo_player_new                 (BraseroDrive    *drive);
+void             goo_player_set_drive           (GooPlayer       *player,
+						 BraseroDrive    *drive);
+BraseroDrive *   goo_player_get_drive           (GooPlayer       *player);
+const char *     goo_player_get_device          (GooPlayer       *player);
+gboolean         goo_player_is_audio_cd         (GooPlayer       *player);
+void             goo_player_hibernate           (GooPlayer       *player,
+						 gboolean         hibernate);
+gboolean         goo_player_is_hibernate        (GooPlayer       *player);
 void             goo_player_update              (GooPlayer       *player);
 void             goo_player_list                (GooPlayer       *player);
-void             goo_player_seek_song           (GooPlayer       *player,
+void             goo_player_seek_track          (GooPlayer       *player,
 						 int              n);
-SongInfo *       goo_player_get_song            (GooPlayer       *player,
-						 int              n);
-int              goo_player_get_current_song    (GooPlayer       *player);
+int              goo_player_get_current_track   (GooPlayer       *player);
 void             goo_player_skip_to             (GooPlayer       *player,
 						 guint            seconds);
 void             goo_player_play                (GooPlayer       *player);
 void             goo_player_pause               (GooPlayer       *player);
 void             goo_player_stop                (GooPlayer       *player);
-gboolean         goo_player_eject               (GooPlayer       *player);
-GError *         goo_player_get_error           (GooPlayer       *player);
-GList *          goo_player_get_song_list       (GooPlayer       *player);
+void             goo_player_eject               (GooPlayer       *player);
 GooPlayerAction  goo_player_get_action          (GooPlayer       *player);
 GooPlayerState   goo_player_get_state           (GooPlayer       *player);
-gboolean         goo_player_set_location        (GooPlayer       *player,
-						 const char      *location);
-const char *     goo_player_get_location        (GooPlayer       *player);
-const char *     goo_player_get_title           (GooPlayer       *player);
-const char *     goo_player_get_subtitle        (GooPlayer       *player);
-int              goo_player_get_volume          (GooPlayer       *player);
-void             goo_player_set_volume          (GooPlayer       *player,
-						 int              vol);
+const char *     goo_player_get_discid          (GooPlayer       *player);
+void             goo_player_set_album           (GooPlayer       *player,
+						 AlbumInfo       *album);
+AlbumInfo *      goo_player_get_album           (GooPlayer       *player);
+void             goo_player_set_audio_volume    (GooPlayer       *player,
+						 double           vol);
+double           goo_player_get_audio_volume    (GooPlayer       *player);
 gboolean         goo_player_get_is_busy         (GooPlayer       *player);
 
-/* protected */
-
-void             goo_player_set_error           (GooPlayer       *player,
-						 GError          *error);
-void             goo_player_set_state           (GooPlayer       *player,
-						 GooPlayerState   state,
-						 gboolean         notify);
-void             goo_player_set_current_song    (GooPlayer       *player,
-						 int              n);
-void             goo_player_set_title           (GooPlayer       *player,
-						 const char      *value);
-void             goo_player_set_subtitle        (GooPlayer       *player,
-						 const char      *value);
-void             goo_player_set_volume_protected(GooPlayer       *player,
-						 int              vol);
-void             goo_player_set_is_busy         (GooPlayer       *player,
-						 gboolean         value);
-
 #endif /* GOO_PLAYER_H */
