@@ -25,24 +25,23 @@
 
 
 #include <config.h>
-#include <gnome.h>
 #include "actions.h"
 #include "goo-stock.h"
 
 
 static GtkActionEntry action_entries[] = {
-	{ "CDMenu", NULL, N_("_CD") },
+	{ "CDMenu", NULL, N_("_Disc") },
 	{ "EditMenu", NULL, N_("_Edit") },
 	{ "ViewMenu", NULL, N_("_View") },
 	{ "HelpMenu", NULL, N_("_Help") },
-	{ "CDCoverMenu", NULL, N_("CD C_over") },
+	{ "CDCoverMenu", NULL, N_("C_over") },
 
-	{ "About", GNOME_STOCK_ABOUT,
-	  N_("_About"), NULL,
+	{ "About", GTK_STOCK_ABOUT,
+	  NULL, NULL,
 	  N_("Information about the program"),
 	  G_CALLBACK (activate_action_about) },
 	{ "Contents", GTK_STOCK_HELP,
-	  N_("_Contents"), "F1",
+	  NULL, "F1",
 	  N_("Display the manual"),
 	  G_CALLBACK (activate_action_manual) },
 	{ "Shortcuts", NULL,
@@ -77,46 +76,58 @@ static GtkActionEntry action_entries[] = {
 	  N_("Pre_v"), "P",
 	  N_("Play the previous track"),
 	  G_CALLBACK (activate_action_prev) },
-	{ "Eject", GOO_STOCK_EJECT,
+	{ "Eject", NULL,
 	  N_("_Eject"), "J",
-	  N_("Eject the CD"),
+	  N_("Eject the disc"),
+	  G_CALLBACK (activate_action_eject) },
+	{ "EjectToolBar", GOO_STOCK_EJECT,
+	  N_("_Eject"), "J",
+	  N_("Eject the disc"),
 	  G_CALLBACK (activate_action_eject) },
-	{ "Reload", GTK_STOCK_REFRESH,
-	  N_("_Reload"), "<control>R",
-	  N_("Reload the CD"),
-	  G_CALLBACK (activate_action_reload) },
 	{ "Preferences", GTK_STOCK_PREFERENCES,
-	  N_("_Preferences"), NULL,
+	  NULL, NULL,
 	  N_("Edit various preferences"),
 	  G_CALLBACK (activate_action_preferences) },
+	{ "CopyDisc", NULL,
+	  N_("_Copy Disc"), "C",
+	  N_("Copy the content of this disc on another disc"),
+	  G_CALLBACK (activate_action_copy_disc) },
 	{ "Extract", GOO_STOCK_EXTRACT,
 	  N_("E_xtract Tracks"), "E",
 	  N_("Save the tracks to disk as files"),
 	  G_CALLBACK (activate_action_extract) },
+	{ "ExtractSelected", GOO_STOCK_EXTRACT,
+	  N_("E_xtract Tracks"), "E",
+	  N_("Save the selected tracks to disk as files"),
+	  G_CALLBACK (activate_action_extract_selected) },
 	{ "Properties", GTK_STOCK_PROPERTIES,
-	  N_("_CD Properties"), NULL,
-	  N_("Edit the CD artist, album and tracks titles"),
-	  G_CALLBACK (activate_action_edit_cddata) },
+	  NULL, "<Ctrl>Return",
+	  N_("Edit the disc artist, album and the tracks titles"),
+	  G_CALLBACK (activate_action_properties) },
 	{ "Quit", GTK_STOCK_QUIT,
-	  N_("_Quit"), NULL,
+	  NULL, NULL,
 	  N_("Quit the application"),
 	  G_CALLBACK (activate_action_quit) },
 	{ "PickCoverFromDisk", GTK_STOCK_OPEN,
-	  N_("_Choose from Disk"), "",
-	  N_("Choose a CD cover from the local disk"),
+	  N_("_Choose File..."), "",
+	  N_("Choose a file to use as disc cover"),
 	  G_CALLBACK (activate_action_pick_cover_from_disk) },
-	{ "SearchCoverFromWeb", GOO_STOCK_WEB,
+	{ "SearchCoverFromWeb", GTK_STOCK_FIND,
 	  N_("_Search on Internet"), NULL,
-	  N_("Search for a CD cover on Internet"),
+	  N_("Search for a disc cover on Internet"),
 	  G_CALLBACK (activate_action_search_cover_on_internet) },
 	{ "RemoveCover", GTK_STOCK_REMOVE,
-	  N_("_Remove Cover"), NULL,
-	  N_("Remove current CD cover"),
+	  NULL, NULL,
+	  N_("Remove current disc cover"),
 	  G_CALLBACK (activate_action_remove_cover) },
 	{ "ToggleVisibility", NULL,
 	  N_("_Hide Window"), NULL /*"H"*/,
 	  N_("Hide the main window"),
 	  G_CALLBACK (activate_action_toggle_visibility) },
+	{ "Reload", GTK_STOCK_REFRESH,
+	  NULL, "<Ctrl>R",
+	  NULL,
+	  G_CALLBACK (activate_action_reload) }
 };
 static guint n_action_entries = G_N_ELEMENTS (action_entries);
 
@@ -125,12 +136,12 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 	{ "ViewToolbar", NULL,
 	  N_("_Toolbar"), NULL,
 	  N_("View the main toolbar"),
-	  G_CALLBACK (activate_action_view_toolbar), 
+	  G_CALLBACK (activate_action_view_toolbar),
 	  TRUE },
 	{ "ViewStatusbar", NULL,
 	  N_("Stat_usbar"), NULL,
 	  N_("View the statusbar"),
-	  G_CALLBACK (activate_action_view_statusbar), 
+	  G_CALLBACK (activate_action_view_statusbar),
 	  TRUE },
 	{ "PlayAll", NULL,
 	  N_("Play _All"), NULL,
@@ -151,33 +162,35 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 static guint n_action_toggle_entries = G_N_ELEMENTS (action_toggle_entries);
 
 
-static const gchar *ui_info = 
+static const gchar *ui_info =
 "<ui>"
 "  <menubar name='MenuBar'>"
 "    <menu action='CDMenu'>"
+"      <menuitem action='Extract'/>"
+"      <menuitem action='CopyDisc'/>"
+"      <menuitem action='Eject'/>"
+"      <separator />"
 "      <menuitem action='TogglePlay'/>"
 "      <menuitem action='Stop'/>"
 "      <menuitem action='Next'/>"
 "      <menuitem action='Prev'/>"
-"      <menuitem action='Eject'/>"
-"      <separator name='sep01'/>"
-"      <menuitem action='Extract'/>"
-"      <separator name='sep02'/>"
+"      <separator />"
+"      <menuitem action='Properties'/>"
+"      <separator />"
 "      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='EditMenu'>"
 "      <menuitem action='PlayAll'/>"
 "      <menuitem action='Repeat'/>"
 "      <menuitem action='Shuffle'/>"
-"      <separator name='sep01'/>"
-"      <menuitem action='Properties'/>"
+"      <separator/>"
 "      <menu action='CDCoverMenu'>"
 "        <menuitem action='PickCoverFromDisk'/>"
 "        <menuitem action='SearchCoverFromWeb'/>"
-"        <separator name='sep01'/>"
+"        <separator/>"
 "        <menuitem action='RemoveCover'/>"
 "      </menu>"
-"      <separator name='sep02'/>"
+"      <separator/>"
 "      <menuitem action='Preferences'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
@@ -192,19 +205,20 @@ static const gchar *ui_info =
 "    </menu>"
 "  </menubar>"
 "  <toolbar  name='ToolBar'>"
+"    <toolitem action='TogglePlay'/>"
 "    <toolitem action='Play'/>"
 "    <toolitem action='Pause'/>"
 "    <toolitem action='Next'/>"
-"    <separator name='sep01'/>"
-"    <toolitem action='Eject'/>"
+"    <separator />"
+"    <toolitem action='Extract'/>"
+"    <toolitem action='EjectToolBar'/>"
 "  </toolbar>"
 "  <popup name='ListPopupMenu'>"
 "    <menuitem action='PlaySelected'/>"
-"    <menuitem action='Extract'/>"
+"    <menuitem action='ExtractSelected'/>"
 "  </popup>"
 "  <popup name='TrayPopupMenu'>"
 "    <menuitem action='TogglePlay'/>"
-"    <menuitem action='Stop'/>"
 "    <menuitem action='Next'/>"
 "    <menuitem action='Eject'/>"
 "    <separator/>"
